# KeywordV30Rc2

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**created_date** | [**CreatedDateV30Rc2**](CreatedDateV30Rc2.md) |  | [optional] 
**last_modified_date** | [**LastModifiedDateV30Rc2**](LastModifiedDateV30Rc2.md) |  | [optional] 
**source** | [**SourceV30Rc2**](SourceV30Rc2.md) |  | [optional] 
**content** | **str** |  | [optional] 
**visibility** | **str** |  | [optional] 
**path** | **str** |  | [optional] 
**put_code** | **int** |  | [optional] 
**display_index** | **int** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

